package graphql

import (
	"context"
	"github.com/gshopify/service-wrapper/auth"
	"gshopper.com/gshopify/customer/graphql/generated"
)

func (r *mutationResolver) CustomerAccessTokenDelete(
	ctx context.Context, t string) (*generated.CustomerAccessTokenDeletePayload, error) {

	var (
		response  = &generated.CustomerAccessTokenDeletePayload{}
		session   = auth.SessionManager()
		sessionId string
		err       error
	)

	_, sessionId, err = r.decodeAccessToken(ctx, t)
	if err != nil {
		response.UserErrors = append(response.UserErrors, ErrToken(err.Error()))
		return response, nil
	}

	refresh, err := session.Token(ctx, sessionId)
	if err != nil {
		response.UserErrors = append(response.UserErrors, ErrToken(err.Error()))
		return response, nil
	}

	if err = r.client.Logout(ctx, r.conf.Cli.ClientId, r.conf.Cli.ClientSecret, r.conf.Cli.Realm, refresh); err != nil {
		response.UserErrors = append(response.UserErrors, ErrToken(err.Error()))
		return response, nil
	}

	response.DeletedAccessToken = &t
	response.DeletedCustomerAccessTokenID = &sessionId
	return response, nil
}
