package graphql

import (
	"context"
	"github.com/gshopify/service-wrapper/auth"
	"github.com/gshopify/service-wrapper/scalar"
	"gshopper.com/gshopify/customer/graphql/generated"
)

func (r *mutationResolver) CustomerAccessTokenRenew(ctx context.Context, t string) (*generated.CustomerAccessTokenRenewPayload, error) {
	var (
		response  = &generated.CustomerAccessTokenRenewPayload{}
		session   = auth.SessionManager()
		sessionId string
		err       error
	)

	_, sessionId, err = r.decodeAccessToken(ctx, t)
	if err != nil {
		response.UserErrors = append(response.UserErrors, ErrTokenNotExists)
		return response, nil
	}

	refresh, err := session.Token(ctx, sessionId)
	if err != nil {
		response.UserErrors = append(response.UserErrors, ErrToken(err.Error()))
		return response, nil
	}

	token, err := r.client.RefreshToken(ctx, refresh, r.conf.Cli.ClientId, r.conf.Cli.ClientSecret, r.conf.Cli.Realm)
	if err != nil {
		response.UserErrors = append(response.UserErrors, ErrTokenExpired)
		return response, nil
	}

	if err = r.saveSession(ctx, token); err != nil {
		response.UserErrors = append(response.UserErrors, ErrToken(err.Error()))
		return response, nil
	}

	response.CustomerAccessToken = &generated.CustomerAccessToken{
		AccessToken: token.AccessToken,
		ExpiresAt:   scalar.NewDateTimeIn(token.RefreshExpiresIn),
	}
	return response, nil
}
